Installation
============

You can install Versioned HDF5 via pypi with

.. code::

   pip install versioned-hdf5

Dependencies
------------

Currently, Versioned HDF5 has the following runtime dependencies:

- ``python>=3.6``
- ``numpy``
- ``h5py``
- ``ndindex``
